Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(627)

Unified Diff: logdog/appengine/cmd/coordinator/vmuser/doc.go

Issue 2591443002: Use classic GAE for coordinator default frontend. (Closed)
Patch Set: Rebase Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | logdog/appengine/cmd/coordinator/vmuser/main.go » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: logdog/appengine/cmd/coordinator/vmuser/doc.go
diff --git a/logdog/appengine/cmd/coordinator/vmuser/doc.go b/logdog/appengine/cmd/coordinator/vmuser/doc.go
index fe785120e6a017feef9d783946ecf83561a5e867..b4ca30ea13063d86811de13670500701050abb4c 100644
--- a/logdog/appengine/cmd/coordinator/vmuser/doc.go
+++ b/logdog/appengine/cmd/coordinator/vmuser/doc.go
@@ -2,7 +2,6 @@
// Use of this source code is governed under the Apache License, Version 2.0
// that can be found in the LICENSE file.
-// Package main is the main entry point for the `vmuser` LogDog AppEngine
-// executable. This executable is designed to be built with and deployed on the
-// Google AppEngine Engine Managed VM infrastructure.
-package main
+// Package module is the main entry point for the `vmuser` LogDog AppEngine
+// module.
+package module
« no previous file with comments | « no previous file | logdog/appengine/cmd/coordinator/vmuser/main.go » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698